Module bus

Module bus 

Event bus for dispatching events to registered handlers

Structs

DefaultBindingContext
Default binding context for apps that don’t need custom contexts.
EventBus
Event bus that manages subscriptions and dispatches events.
EventOutcome
Result of mapping an event into actions plus an optional render hint.
HandlerResponse
Response returned by an event handler.
RoutedEvent
Routed event passed to handlers.

Enums

RawEvent
Raw event from crossterm before processing
RouteTarget
Where a handler is being routed in the current event flow.

Traits

EventHandler
Trait for event handlers registered with the bus.
EventRoutingState
State accessors used by the event bus for routing decisions.

Functions

process_raw_event
Process a raw event into an EventKind.
spawn_event_poller
Spawn the event polling task with cancellation support.

Type Aliases

SimpleEventBus
Simplified EventBus for apps that don’t need custom binding contexts.