pub struct Runtime<S, A, E = NoEffect, Routing = Direct, St = Store<S, A, E>>where
A: Action,
St: RuntimeStore<S, A, E>,{ /* private fields */ }Expand description
Runtime helper for store-driven applications.
Implementations
Sourceimpl<S, A, E, Routing, St> Runtime<S, A, E, Routing, St>where
S: 'static,
A: Action,
St: RuntimeStore<S, A, E>,
impl<S, A, E, Routing, St> Runtime<S, A, E, Routing, St>where
S: 'static,
A: Action,
St: RuntimeStore<S, A, E>,
Sourcepub fn with_event_bus<Id, Ctx>(
self,
bus: EventBus<S, A, Id, Ctx>,
keybindings: Keybindings<Ctx>,
) -> Runtime<S, A, E, EventBusRouting<S, A, Id, Ctx>, St>
pub fn with_event_bus<Id, Ctx>( self, bus: EventBus<S, A, Id, Ctx>, keybindings: Keybindings<Ctx>, ) -> Runtime<S, A, E, EventBusRouting<S, A, Id, Ctx>, St>
Pair this runtime with an EventBus + Keybindings so raw events
are routed through the bus before actions are dispatched.
Sourceimpl<S, A, E, Routing, St> Runtime<S, A, E, Routing, St>where
S: 'static,
A: Action,
St: RuntimeStore<S, A, E>,
impl<S, A, E, Routing, St> Runtime<S, A, E, Routing, St>where
S: 'static,
A: Action,
St: RuntimeStore<S, A, E>,
Sourcepub fn with_debug<D>(self, debug: D) -> Runtime<S, A, E, Routing, St>where
D: DebugAdapter<S, A>,
pub fn with_debug<D>(self, debug: D) -> Runtime<S, A, E, Routing, St>where
D: DebugAdapter<S, A>,
Attach a debug layer.
Sourcepub fn with_event_poller(
self,
config: PollerConfig,
) -> Runtime<S, A, E, Routing, St>
pub fn with_event_poller( self, config: PollerConfig, ) -> Runtime<S, A, E, Routing, St>
Configure event polling behavior.
Sourcepub fn with_dispatch_error_handler<F>(
self,
handler: F,
) -> Runtime<S, A, E, Routing, St>
pub fn with_dispatch_error_handler<F>( self, handler: F, ) -> Runtime<S, A, E, Routing, St>
Configure handling for recoverable dispatch errors.
The handler receives each DispatchError and selects a
DispatchErrorPolicy. Runtimes do not log or store errors by default;
do that inside this closure when needed.
Sourcepub fn subscribe_actions(&self) -> Receiver<String>
pub fn subscribe_actions(&self) -> Receiver<String>
Subscribe to action name broadcasts.
Sourcepub fn action_tx(&self) -> UnboundedSender<A>
pub fn action_tx(&self) -> UnboundedSender<A>
Clone the action sender.