pub struct LoggingMiddleware {
pub log_before: bool,
pub log_after: bool,
}Expand description
Middleware that logs actions (for debugging)
Fields
log_before: boolWhether to log before dispatch
log_after: boolWhether to log after dispatch
Implementations
Sourceimpl LoggingMiddleware
impl LoggingMiddleware
Sourcepub fn new() -> LoggingMiddleware
pub fn new() -> LoggingMiddleware
Create a new logging middleware with default settings (log after only)
Sourcepub fn verbose() -> LoggingMiddleware
pub fn verbose() -> LoggingMiddleware
Create a logging middleware that logs both before and after