pub struct ReducerResult<E> {
pub changed: bool,
pub effects: Vec<E>,
}Expand description
Result of dispatching an action to an effect-aware store.
Contains both the state change indicator and any effects to be processed.
Fields
changed: boolWhether the state was modified by this action.
effects: Vec<E>Effects to be processed after dispatch.
Implementations
Sourceimpl<E> ReducerResult<E>
impl<E> ReducerResult<E>
Sourcepub fn unchanged() -> ReducerResult<E>
pub fn unchanged() -> ReducerResult<E>
Create a result indicating no state change and no effects.
Sourcepub fn changed() -> ReducerResult<E>
pub fn changed() -> ReducerResult<E>
Create a result indicating state changed but no effects.
Sourcepub fn effect(effect: E) -> ReducerResult<E>
pub fn effect(effect: E) -> ReducerResult<E>
Create a result with a single effect but no state change.
Sourcepub fn effects(effects: Vec<E>) -> ReducerResult<E>
pub fn effects(effects: Vec<E>) -> ReducerResult<E>
Create a result with multiple effects but no state change.
Sourcepub fn changed_with(effect: E) -> ReducerResult<E>
pub fn changed_with(effect: E) -> ReducerResult<E>
Create a result indicating state changed with a single effect.
Sourcepub fn changed_with_many(effects: Vec<E>) -> ReducerResult<E>
pub fn changed_with_many(effects: Vec<E>) -> ReducerResult<E>
Create a result indicating state changed with multiple effects.
Sourcepub fn with(self, effect: E) -> ReducerResult<E>
pub fn with(self, effect: E) -> ReducerResult<E>
Add an effect to this result.
Sourcepub fn mark_changed(self) -> ReducerResult<E>
pub fn mark_changed(self) -> ReducerResult<E>
Set the changed flag to true.
Sourcepub fn has_effects(&self) -> bool
pub fn has_effects(&self) -> bool
Returns true if there are any effects to process.