pub type Reducer<S, A, E = NoEffect> = fn(&mut S, A) -> ReducerResult<E>;Expand description
A reducer function that handles actions and mutates state
Returns a ReducerResult containing the state change flag and any effects
emitted by the action.
pub type Reducer<S, A, E = NoEffect> = fn(&mut S, A) -> ReducerResult<E>;A reducer function that handles actions and mutates state
Returns a ReducerResult containing the state change flag and any effects
emitted by the action.