Event bus for dispatching events to registered handlers
Structs
- Default
Binding Context - Default binding context for apps that don’t need custom contexts.
- Event
Bus - Event bus that manages subscriptions and dispatches events.
- Event
Outcome - Result of mapping an event into actions plus an optional render hint.
- Handler
Response - Response returned by an event handler.
- Routed
Event - Routed event passed to handlers.
Enums
- RawEvent
- Raw event from crossterm before processing
- Route
Target - Where a handler is being routed in the current event flow.
Traits
- Event
Handler - Trait for event handlers registered with the bus.
- Event
Routing State - State accessors used by the event bus for routing decisions.
Functions
- process_
raw_ event - Process a raw event into an EventKind.
- spawn_
event_ poller - Spawn the event polling task with cancellation support.
Type Aliases
- Simple
Event Bus - Simplified EventBus for apps that don’t need custom binding contexts.